@@ -17,6 +17,7 @@ var hierarchy =
     [ "processes::callback_data_block", "classprocesses_1_1callback__data__block.html", [
       [ "processes::mail_stop::items_to_deliver", "classprocesses_1_1mail__stop_1_1items__to__deliver.html", null ]
     ] ],
+    [ "application::callstack_tracker", "classapplication_1_1callstack__tracker.html", null ],
     [ "structures::checksums", "classstructures_1_1checksums.html", null ],
     [ "geometric::circle", "classgeometric_1_1circle.html", null ],
     [ "application::command_line", "classapplication_1_1command__line.html", null ],
@@ -42,6 +43,7 @@ var hierarchy =
     [ "filepointer", "structfilepointer.html", null ],
     [ "org.gffs.filesystem.FileSystemHelper", "classorg_1_1gffs_1_1filesystem_1_1FileSystemHelper.html", null ],
     [ "fix_project_references.fix_project_references", "classfix__project__references_1_1fix__project__references.html", null ],
+    [ "application::frame_tracking_instance", "classapplication_1_1frame__tracking__instance.html", null ],
     [ "algorithms::heap< type >", "classalgorithms_1_1heap.html", null ],
     [ "filesystem::huge_file", "classfilesystem_1_1huge__file.html", null ],
     [ "org.feistymeow.dragdrop.IDragonDropDataProvider", "interfaceorg_1_1feistymeow_1_1dragdrop_1_1IDragonDropDataProvider.html", [
